@@ -5,9 +5,11 @@ use warnings;
 use POSIX;
 use Carp qw{ croak };
 
+use List::Util qw/max/;
+
 our @ISA = qw();
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 sub show_bar {
     my $num     = shift || 0;
@@ -49,14 +51,25 @@ sub show_labeled_graph {
     }
     my %k_values = %{ $args{'k_values'} };
 
-    my $str = q{};
+    my $label_width = max_label_width( keys %k_values );
+    my $bar_width   = $columns - $label_width - 2;
+    my $str         = q{};
+
+    my $bar = q{};
     for my $i ( keys %k_values ) {
-        $str .= sprintf( "%10s %s\n", $i, show_bar($k_values{$i}, $max, $columns) );
+        $bar = show_bar($k_values{$i}, $max, $bar_width);
+        print $i . "->" . $k_values{$i};
+        print "\n";
+        $str .= sprintf( '%' . $label_width . "s %s\n", $i, $bar );
     }
 
     return $str;
 }
 
+sub max_label_width {
+    return 1 + max map { length $_ } @_;
+}
+
 1;
 
 __END__
